#!/usr/bin/perl

use strict;
use HSPC::WebDB qw(:DEFAULT atrans trans);

use Storable qw(freeze);
use HSPC::PluginToolkit::General qw(last_month_day);

my $cards = select_hashrows(q|
	SELECT
		p.id, p.paytype_id, p.pdata_id, p.name, p.account_no,
		p.is_online, p.is_enabled, p.status, p.customer_ip,
		c.expire_date,p.user_comment,p.admin_comment
	FROM
		paymethod p, paymethod_creditcard c
	WHERE
		p.id=c.id
|);

foreach my $card (@$cards) {
	my %hash = ( expire_date => $card->{expire_date} );
	my $trans = trans();
	select_run(q|
		INSERT INTO plugin_pm (
			id, type, name, account_no, enabled, recurring,
			status, template_id, customer_ip, expire_date,
			data_id, public_data, checksum
		) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, NULL)|,
		$card->{id}, $card->{paytype_id}, $card->{name}, $card->{account_no},
		$card->{is_enabled}, $card->{is_online}, $card->{status}, 'OP_CCard',
		$card->{customer_ip}, last_month_day($card->{expire_date}),
		$card->{pdata_id}, freeze(\%hash)
	);
	select_run(q|
		INSERT INTO core_comment (node_id,node_type,
		create_date,comment_type,added_by,added_by_account,added_by_ip,
		is_public,comment_txt) VALUES (?,?,?,?,?,?,?,?,?)|,$card->{id},
		'HSPC::MT::PM::PluginEngine::BankAccount','0000-00-00 00:00:00',
		1,1,1,undef,1,$card->{user_comment}
	) if ( $card->{user_comment} );
	select_run(q|
		INSERT INTO core_comment (node_id,node_type,
		create_date,comment_type,added_by,added_by_account,added_by_ip,
		is_public,comment_txt) VALUES (?,?,?,?,?,?,?,?,?)|,$card->{id},
		'HSPC::MT::PM::PluginEngine::BankAccount','0000-00-00 00:00:00',
		1,1,1,undef,0,$card->{admin_comment}
	) if ( $card->{admin_comment} );

	select_run("delete from paymethod where paymethod.id = '$card->{id}'");
	select_run("delete from paymethod_creditcard where paymethod_creditcard.id = '$card->{id}'");
	$trans->commit();
}

